@@ -620,7 +620,7 @@ class Channel(callbacks.Plugin):
             If you have the #channel,op capability, this will show you the
             current persistent bans on the <channel> that match the given
             mask, if any (returns all of them otherwise).
-            Note that you can use * as a wildcard on masks and \* to match
+            Note that you can use * as a wildcard on masks and \\* to match
             actual * in masks
             """
             all_bans = ircdb.channels.getChannel(channel).bans
