@@ -90,13 +90,13 @@ class ChannelLogger(callbacks.Plugin):
                 if e.args[0] != 'I/O operation on a closed file':
                     self.log.exception('Odd exception:')
 
-    def logNameTimestamp(self, channel):
-        format = self.registryValue('filenameTimestamp', channel)
+    def logNameTimestamp(self, network, channel):
+        format = self.registryValue('filenameTimestamp', channel, network)
         return time.strftime(format)
 
-    def getLogName(self, channel):
-        if self.registryValue('rotateLogs', channel):
-            name = '%s.%s.log' % (channel, self.logNameTimestamp(channel))
+    def getLogName(self, network, channel):
+        if self.registryValue('rotateLogs', channel, network):
+            name = '%s.%s.log' % (channel, self.logNameTimestamp(network, channel))
         else:
             name = '%s.log' % channel
         return utils.file.sanitizeName(name)
@@ -108,7 +108,7 @@ class ChannelLogger(callbacks.Plugin):
             if self.registryValue('directories.network'):
                 logDir = os.path.join(logDir,  irc.network)
             if self.registryValue('directories.channel'):
-                logDir = os.path.join(logDir, channel)
+                logDir = os.path.join(logDir, utils.file.sanitizeName(channel))
             if self.registryValue('directories.timestamp'):
                 format = self.registryValue('directories.timestamp.format')
                 timeDir =time.strftime(format)
@@ -120,8 +120,8 @@ class ChannelLogger(callbacks.Plugin):
     def checkLogNames(self):
         for (irc, logs) in self.logs.items():
             for (channel, log) in list(logs.items()):
-                if self.registryValue('rotateLogs', channel):
-                    name = self.getLogName(channel)
+                if self.registryValue('rotateLogs', channel, irc.network):
+                    name = self.getLogName(irc.network, channel)
                     if name != os.path.basename(log.name):
                         log.close()
                         del logs[channel]
@@ -137,7 +137,7 @@ class ChannelLogger(callbacks.Plugin):
             return logs[channel]
         else:
             try:
-                name = self.getLogName(channel)
+                name = self.getLogName(irc.network, channel)
                 logDir = self.getLogDir(irc, channel)
                 log = open(os.path.join(logDir, name), encoding='utf-8', mode='a')
                 logs[channel] = log
@@ -158,14 +158,14 @@ class ChannelLogger(callbacks.Plugin):
         return ircutils.toLower(channel)
 
     def doLog(self, irc, channel, s, *args):
-        if not self.registryValue('enable', channel):
+        if not self.registryValue('enable', channel, irc.network):
             return
         s = format(s, *args)
         channel = self.normalizeChannel(irc, channel)
         log = self.getLog(irc, channel)
-        if self.registryValue('timestamp', channel):
+        if self.registryValue('timestamp', channel, irc.network):
             self.timestamp(log)
-        if self.registryValue('stripFormatting', channel):
+        if self.registryValue('stripFormatting', channel, irc.network):
             s = ircutils.stripFormatting(s)
         if minisix.PY2:
             s = s.decode('utf8', 'ignore')
@@ -177,7 +177,8 @@ class ChannelLogger(callbacks.Plugin):
         (recipients, text) = msg.args
         for channel in recipients.split(','):
             if irc.isChannel(channel):
-                noLogPrefix = self.registryValue('noLogPrefix', channel)
+                noLogPrefix = self.registryValue('noLogPrefix',
+                                                 channel, irc.network)
                 cap = ircdb.makeChannelCapability(channel, 'logChannelMessages')
                 try:
                     logChannelMessages = ircdb.checkCapability(msg.prefix, cap,
@@ -219,7 +220,7 @@ class ChannelLogger(callbacks.Plugin):
 
     def doJoin(self, irc, msg):
         for channel in msg.args[0].split(','):
-            if(self.registryValue('showJoinParts', channel)):
+            if(self.registryValue('showJoinParts', channel, irc.network)):
                 self.doLog(irc, channel,
                            '*** %s <%s> has joined %s\n',
                            msg.nick, msg.prefix, channel)
@@ -244,7 +245,7 @@ class ChannelLogger(callbacks.Plugin):
         else:
             reason = ""
         for channel in msg.args[0].split(','):
-            if(self.registryValue('showJoinParts', channel)):
+            if(self.registryValue('showJoinParts', channel, irc.network)):
                 self.doLog(irc, channel,
                            '*** %s <%s> has left %s%s\n',
                            msg.nick, msg.prefix, channel, reason)
@@ -270,7 +271,7 @@ class ChannelLogger(callbacks.Plugin):
         else:
             reason = ""
         for channel in msg.tagged('channels'):
-            if(self.registryValue('showJoinParts', channel)):
+            if(self.registryValue('showJoinParts', channel, irc.network)):
                 self.doLog(irc, channel,
                            '*** %s <%s> has quit IRC%s\n',
                            msg.nick, msg.prefix, reason)
