@@ -58,7 +58,7 @@ class GoogleTestCase(ChannelPluginTestCase):
             self.assertRegexp(
                     'google site:http://www.urbandictionary.com carajo land',
                     '\x02Urban Dictionary: carajo land\x02: '
-                    'https?://www.urbandictionary.com/define.php\?term=carajo%20land')
+                    r'https?://www.urbandictionary.com/define.php\?term=carajo%20land')
 
         def testLucky(self):
             self.assertResponse('lucky Hacker News',
