@@ -135,6 +135,12 @@ class MathTestCase(PluginTestCase):
     def testCalcStrFloat(self):
         self.assertResponse('calc 3+33333333333333', '33333333333336')
 
+    def testCalcMemoryError(self):
+        self.assertRegexp('calc ' + '('*10000,
+            '(too much recursion'  # cpython
+            '|parenthesis is never closed)'  # pypy
+        )
+
     def testICalc(self):
         self.assertResponse('icalc 1^1', '0')
         self.assertResponse('icalc 10**24', '1' + '0'*24)
