@@ -30,7 +30,6 @@
 
 import re
 import os
-import imp
 import sys
 import json
 import time
@@ -58,12 +57,6 @@ _ = PluginInternationalization('Misc')
 if minisix.PY2:
     from itertools import ifilter as filter
 
-def get_suffix(file):
-    for suffix in imp.get_suffixes():
-        if file[-len(suffix[0]):] == suffix[0]:
-            return suffix
-    return None
-
 def getPluginsInDirectory(directory):
     # get modules in a given directory
     plugins = []
@@ -155,7 +148,7 @@ class Misc(callbacks.Plugin):
                 return
         # Now, for normal handling.
         if conf.supybot.reply.whenNotCommand.getSpecific(
-                channel, irc.network)():
+                irc.network, channel)():
             if len(tokens) >= 2:
                 cb = irc.getCallback(tokens[0])
                 if cb:
@@ -179,7 +172,7 @@ class Misc(callbacks.Plugin):
                     if channel != irc.nick else _('private'))
             if irc.nested:
                 bracketConfig = conf.supybot.commands.nested.brackets
-                brackets = bracketConfig.getSpecific(channel, irc.network)()
+                brackets = bracketConfig.getSpecific(irc.network, channel)()
                 if brackets:
                     (left, right) = brackets
                     irc.reply(left + ' '.join(tokens) + right)
