@@ -116,9 +116,9 @@ class StringTestCase(PluginTestCase):
         self.assertResponse('re s/user/luser/g user user', 'luser luser')
         self.assertResponse('re s/user/luser/ user user', 'luser user')
         self.assertNotRegexp('re m/foo/ bar', 'has no attribute')
-        self.assertResponse('re m/a\S+y/ "the bot angryman is hairy"','angry')
-        self.assertResponse('re m/a\S+y/g "the bot angryman is hairy"',
-                'angry and airy')
+        self.assertResponse('re m/a\\S+y/ "the bot angryman is hairy"', 'angry')
+        self.assertResponse('re m/a\\S+y/g "the bot angryman is hairy"',
+                            'angry and airy')
 
     def testReNotEmptyString(self):
         self.assertError('re s//foo/g blah')
@@ -130,7 +130,7 @@ class StringTestCase(PluginTestCase):
         self.assertNotRegexp('re foo bar baz', 'unpack list of wrong size')
 
     def testReBug850931(self):
-        self.assertResponse('re s/\b(\w+)\b/\1./g foo bar baz',
+        self.assertResponse(r're s/\b(\w+)\b/\1./g foo bar baz',
                             'foo. bar. baz.')
 
     def testNotOverlongRe(self):
