@@ -50,7 +50,7 @@ __contributors__ = {supybot.authors.progval: ['tztime'],
 
 from . import config
 from . import plugin
-from imp import reload
+from importlib import reload
 reload(plugin) # In case we're being reloaded.
 # Add more reloads here if you add third-party modules and want them to be
 # reloaded when this plugin is reloaded.  Don't forget to import them as well!
