@@ -123,9 +123,9 @@ def process(f, *args, **kwargs):
             resource.setrlimit(rsrc, (soft, hard))
         try:
             r = f(*args, **kwargs)
-            q.put(r)
+            q.put([False, r])
         except Exception as e:
-            q.put(e)
+            q.put([True, e])
     targetArgs = (f, q,) + args
     p = callbacks.CommandProcess(target=newf,
                                 args=targetArgs, kwargs=kwargs)
@@ -136,19 +136,20 @@ def process(f, *args, **kwargs):
         q.close()
         raise ProcessTimeoutError("%s aborted due to timeout." % (p.name,))
     try:
-        v = q.get(block=False)
+        raised, v = q.get(block=False)
     except minisix.queue.Empty:
         return None
     finally:
         q.close()
-    if isinstance(v, Exception):
+
+    if raised:
         raise v
     else:
         return v
 
 def regexp_wrapper(s, reobj, timeout, plugin_name, fcn_name):
     '''A convenient wrapper to stuff regexp search queries through a subprocess.
-    
+
     This is used because specially-crafted regexps can use exponential time
     and hang the bot.'''
     def re_bool(s, reobj):
@@ -162,7 +163,7 @@ def regexp_wrapper(s, reobj, timeout, plugin_name, fcn_name):
         v = process(re_bool, s, reobj, timeout=timeout, pn=plugin_name, cn=fcn_name)
         return v
     except ProcessTimeoutError:
-        return False
+        return None
 
 class UrlSnarfThread(world.SupyThread):
     def __init__(self, *args, **kwargs):
@@ -205,9 +206,12 @@ def urlSnarfer(f):
     """Protects the snarfer from loops (with other bots) and whatnot."""
     def newf(self, irc, msg, match, *L, **kwargs):
         url = match.group(0)
-        channel = msg.args[0]
-        if not irc.isChannel(channel) or (ircmsgs.isCtcp(msg) and not
-                                          ircmsgs.isAction(msg)):
+        channel = msg.channel
+        if not channel:
+            # Don't snarf in private
+            return
+        if ircmsgs.isCtcp(msg) and not ircmsgs.isAction(msg):
+            # Don't snarf CTCPs unless they are a /me
             return
         if ircdb.channels.getChannel(channel).lobotomized:
             self.log.debug('Not snarfing in %s: lobotomized.', channel)
@@ -491,10 +495,11 @@ def getChannel(irc, msg, args, state):
         return
     if args and irc.isChannel(args[0]):
         channel = args.pop(0)
-    elif irc.isChannel(msg.args[0]):
-        channel = msg.args[0]
+    elif msg.channel:
+        channel = msg.channel
     else:
         state.log.debug('Raising ArgumentError because there is no channel.')
+        print(msg.channel, msg)
         raise callbacks.ArgumentError
     state.channel = channel
     state.args.append(channel)
@@ -502,8 +507,8 @@ def getChannel(irc, msg, args, state):
 def getChannels(irc, msg, args, state):
     if args and all(map(irc.isChannel, args[0].split(','))):
         channels = args.pop(0).split(',')
-    elif irc.isChannel(msg.args[0]):
-        channels = [msg.args[0]]
+    elif msg.channel:
+        channels = [msg.channel]
     else:
         state.log.debug('Raising ArgumentError because there is no channel.')
         raise callbacks.ArgumentError
@@ -535,11 +540,11 @@ def inChannel(irc, msg, args, state):
         state.error(_('I\'m not in %s.') % state.channel, Raise=True)
 
 def onlyInChannel(irc, msg, args, state):
-    if not (irc.isChannel(msg.args[0]) and msg.args[0] in irc.state.channels):
+    if not (msg.channel and msg.channel in irc.state.channels):
         state.error(_('This command may only be given in a channel that I am '
                     'in.'), Raise=True)
     else:
-        state.channel = msg.args[0]
+        state.channel = msg.channel
         state.args.append(state.channel)
 
 def callerInGivenChannel(irc, msg, args, state):
@@ -576,8 +581,8 @@ def getChannelOrGlobal(irc, msg, args, state):
     elif args and irc.isChannel(args[0]):
         channel = args.pop(0)
         state.channel = channel
-    elif irc.isChannel(msg.args[0]):
-        channel = msg.args[0]
+    elif msg.channel:
+        channel = msg.channel
         state.channel = channel
     else:
         state.log.debug('Raising ArgumentError because there is no channel.')
@@ -620,11 +625,11 @@ def getSomethingNoSpaces(irc, msg, args, state, *L):
     getSomething(irc, msg, args, state, p=p, *L)
 
 def private(irc, msg, args, state):
-    if irc.isChannel(msg.args[0]):
+    if msg.channel:
         state.errorRequiresPrivacy(Raise=True)
 
 def public(irc, msg, args, state, errmsg=None):
-    if not irc.isChannel(msg.args[0]):
+    if not msg.channel:
         if errmsg is None:
             errmsg = _('This message must be sent in a channel.')
         state.error(errmsg, Raise=True)
