@@ -195,8 +195,9 @@ class RealSupyHTTPServer(HTTPServer):
         self.callbacks[subdir] = callback
         callback.doHook(self, subdir)
     def unhook(self, subdir):
-        callback = self.callbacks.pop(subdir) # May raise a KeyError. We don't care.
-        callback.doUnhook(self)
+        callback = self.callbacks.pop(subdir, None)
+        if callback:
+            callback.doUnhook(self)
         return callback
 
     def __str__(self):
@@ -468,7 +469,7 @@ def unhook(subdir):
     """Unsets the callback assigned to the given subdir, and return it."""
     global http_servers
     assert isinstance(http_servers, list)
-    for server in http_servers:
+    for server in list(http_servers):
         server.unhook(subdir)
         if len(server.callbacks) <= 0 and not configGroup.keepAlive():
             server.shutdown()
