@@ -33,6 +33,7 @@ import time
 import random
 import base64
 import textwrap
+import warnings
 import collections
 
 try:
@@ -70,9 +71,39 @@ MAX_LINE_SIZE = 512 # Including \r\n
 
 class IrcCommandDispatcher(object):
     """Base class for classes that must dispatch on a command."""
-    def dispatchCommand(self, command):
+
+    def dispatchCommand(self, command, args=None):
         """Given a string 'command', dispatches to doCommand."""
-        return getattr(self, 'do' + command.capitalize(), None)
+        if args is None:
+            warnings.warn(
+                "dispatchCommand now takes an 'args' attribute, which is "
+                "a list of the command's arguments (ie. IrcMsg.args).",
+                DeprecationWarning)
+            args = []
+
+        command = command.upper()
+        subcommand = None
+        method = None
+
+        # Dispatch on command + subcommand, if there is a subcommand, and
+        # a method with the matching name exists
+        if command in ('FAIL', 'WARN', 'NOTE') and len(args) >= 1:
+            subcommand = args[0]
+        elif command in ('CAP',) and len(args) >= 2:
+            # Note: this only covers the server-to-client format
+            subcommand = args[1]
+
+        command = command.capitalize()
+
+        if subcommand is not None:
+            subcommand = subcommand.capitalize()
+            method = getattr(self, 'do' + command + subcommand, None)
+
+        # If not dispatched on command + subcommand, then dispatch on command
+        if method is None:
+            method = getattr(self, 'do' + command, None)
+
+        return method
 
 
 class IrcCallback(IrcCommandDispatcher, log.Firewalled):
@@ -141,7 +172,7 @@ class IrcCallback(IrcCommandDispatcher, log.Firewalled):
 
     def __call__(self, irc, msg):
         """Used for handling each message."""
-        method = self.dispatchCommand(msg.command)
+        method = self.dispatchCommand(msg.command, msg.args)
         if method is not None:
             method(irc, msg)
 
@@ -429,7 +460,7 @@ class IrcState(IrcCommandDispatcher, log.Firewalled):
             assert batch in self.batches, \
                     'Server references undeclared batch %s' % batch
             self.batches[batch].messages.append(msg)
-        method = self.dispatchCommand(msg.command)
+        method = self.dispatchCommand(msg.command, msg.args)
         if method is not None:
             method(irc, msg)
 
@@ -944,7 +975,7 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
                 log.debug('Updating server attribute to %s.', self.server)
 
         # Dispatch to specific handlers for commands.
-        method = self.dispatchCommand(msg.command)
+        method = self.dispatchCommand(msg.command, msg.args)
         if method is not None:
             method(msg)
         elif self._numericErrorCommandRe.search(msg.command):
@@ -1143,7 +1174,7 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
 
         mechanism = self.sasl_current_mechanism
         if mechanism == 'ecdsa-nist256p-challenge':
-            self.doAuthenticateEcdsa(string)
+            self._doAuthenticateEcdsa(string)
         elif mechanism == 'external':
             self.sendSaslString(b'')
         elif mechanism.startswith('scram-'):
@@ -1152,15 +1183,15 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
                 if step == 'uninitialized':
                     log.debug('%s: starting SCRAM.',
                             self.network)
-                    self.doAuthenticateScramFirst(mechanism)
+                    self._doAuthenticateScramFirst(mechanism)
                 elif step == 'first-sent':
                     log.debug('%s: received SCRAM challenge.',
                             self.network)
-                    self.doAuthenticateScramChallenge(string)
+                    self._doAuthenticateScramChallenge(string)
                 elif step == 'final-sent':
                     log.debug('%s: finishing SCRAM.',
                             self.network)
-                    self.doAuthenticateScramFinish(string)
+                    self._doAuthenticateScramFinish(string)
                 else:
                     assert False
             except scram.ScramException:
@@ -1175,7 +1206,7 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
             ])
             self.sendSaslString(authstring)
 
-    def doAuthenticateEcdsa(self, string):
+    def _doAuthenticateEcdsa(self, string):
         if string == b'':
             self.sendSaslString(self.sasl_username.encode('utf-8'))
             return
@@ -1192,7 +1223,7 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
                 args=('*',)))
             self.tryNextSaslMechanism()
 
-    def doAuthenticateScramFirst(self, mechanism):
+    def _doAuthenticateScramFirst(self, mechanism):
         """Handle sending the client-first message of SCRAM auth."""
         hash_name = mechanism[len('scram-'):]
         if hash_name.endswith('-plus'):
@@ -1213,13 +1244,13 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
         self.sendSaslString(client_first)
         self.sasl_scram_state['step'] = 'first-sent'
 
-    def doAuthenticateScramChallenge(self, challenge):
+    def _doAuthenticateScramChallenge(self, challenge):
         client_final = self.sasl_scram_state['authenticator'] \
                 .challenge(challenge)
         self.sendSaslString(client_final)
         self.sasl_scram_state['step'] = 'final-sent'
 
-    def doAuthenticateScramFinish(self, data):
+    def _doAuthenticateScramFinish(self, data):
         try:
             res = self.sasl_scram_state['authenticator'] \
                     .finish(data)
@@ -1260,18 +1291,6 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
                  self.network, msg.args[1])
         self.filterSaslMechanisms(set(msg.args[1].split(',')))
 
-    def doCap(self, msg):
-        subcommand = msg.args[1]
-        if subcommand == 'ACK':
-            self.doCapAck(msg)
-        elif subcommand == 'NAK':
-            self.doCapNak(msg)
-        elif subcommand == 'LS':
-            self.doCapLs(msg)
-        elif subcommand == 'DEL':
-            self.doCapDel(msg)
-        elif subcommand == 'NEW':
-            self.doCapNew(msg)
     def doCapAck(self, msg):
         if len(msg.args) != 3:
             log.warning('Bad CAP ACK from server: %r', msg)
