@@ -74,25 +74,25 @@ class FunctionsTestCase(SupyTestCase):
 class ValuesTestCase(SupyTestCase):
     def testBoolean(self):
         v = registry.Boolean(True, """Help""")
-        self.failUnless(v())
+        self.assertTrue(v())
         v.setValue(False)
-        self.failIf(v())
+        self.assertFalse(v())
         v.set('True')
-        self.failUnless(v())
+        self.assertTrue(v())
         v.set('False')
-        self.failIf(v())
+        self.assertFalse(v())
         v.set('On')
-        self.failUnless(v())
+        self.assertTrue(v())
         v.set('Off')
-        self.failIf(v())
+        self.assertFalse(v())
         v.set('enable')
-        self.failUnless(v())
+        self.assertTrue(v())
         v.set('disable')
-        self.failIf(v())
+        self.assertFalse(v())
         v.set('toggle')
-        self.failUnless(v())
+        self.assertTrue(v())
         v.set('toggle')
-        self.failIf(v())
+        self.assertFalse(v())
 
     def testInteger(self):
         v = registry.Integer(1, 'help')
@@ -179,7 +179,7 @@ class ValuesTestCase(SupyTestCase):
         v = registry.Regexp(None, 'help')
         self.assertEqual(v(), None)
         v.set('m/foo/')
-        self.failUnless(v().match('foo'))
+        self.assertTrue(v().match('foo'))
         v.set('')
         self.assertEqual(v(), None)
         self.assertRaises(registry.InvalidRegistryValue,
