@@ -76,7 +76,7 @@ class GenTest(SupyTestCase):
     def testInsensitivePreservingDict(self):
         ipd = utils.InsensitivePreservingDict
         d = ipd(dict(Foo=10))
-        self.failUnless(d['foo'] == 10)
+        self.assertTrue(d['foo'] == 10)
         self.assertEqual(d.keys(), ['Foo'])
         self.assertEqual(d.get('foo'), 10)
         self.assertEqual(d.get('Foo'), 10)
@@ -84,7 +84,7 @@ class GenTest(SupyTestCase):
     def testFindBinaryInPath(self):
         if os.name == 'posix':
             self.assertEqual(None, utils.findBinaryInPath('asdfhjklasdfhjkl'))
-            self.failUnless(utils.findBinaryInPath('sh').endswith('/bin/sh'))
+            self.assertTrue(utils.findBinaryInPath('sh').endswith('/bin/sh'))
 
     def testExnToString(self):
         try:
@@ -124,11 +124,11 @@ class GenTest(SupyTestCase):
                 for (k, v) in self.L:
                     yield (k, v)
         AL = alist()
-        self.failIf(AL)
+        self.assertFalse(AL)
         AL[1] = 2
         AL[2] = 3
         AL[3] = 4
-        self.failUnless(AL)
+        self.assertTrue(AL)
         self.assertEqual(list(AL.items()), [(1, 2), (2, 3), (3, 4)])
         self.assertEqual(list(AL.items()), [(1, 2), (2, 3), (3, 4)])
         self.assertEqual(list(AL.keys()), [1, 2, 3])
@@ -271,25 +271,25 @@ class StrTest(SupyTestCase):
         for s in L:
             r = utils.str.dqrepr(s)
             self.assertEqual(s, eval(r), s)
-            self.failUnless(r[0] == '"' and r[-1] == '"', s)
+            self.assertTrue(r[0] == '"' and r[-1] == '"', s)
 
     def testPerlReToPythonRe(self):
         f = utils.str.perlReToPythonRe
         r = f('m/foo/')
-        self.failUnless(r.search('foo'))
+        self.assertTrue(r.search('foo'))
         r = f('/foo/')
-        self.failUnless(r.search('foo'))
+        self.assertTrue(r.search('foo'))
         r = f('m/\\//')
-        self.failUnless(r.search('/'))
+        self.assertTrue(r.search('/'))
         r = f('m/cat/i')
-        self.failUnless(r.search('CAT'))
+        self.assertTrue(r.search('CAT'))
         self.assertRaises(ValueError, f, 'm/?/')
 
     def testP2PReDifferentSeparator(self):
         r = utils.str.perlReToPythonRe('m!foo!')
-        self.failUnless(r.search('foo'))
+        self.assertTrue(r.search('foo'))
         r = utils.str.perlReToPythonRe('m{cat}')
-        self.failUnless(r.search('cat'))
+        self.assertTrue(r.search('cat'))
 
     def testPerlReToReplacer(self):
         PRTR = utils.str.perlReToReplacer
@@ -350,7 +350,7 @@ class StrTest(SupyTestCase):
         self.assertEqual(f(L, comma=';', And='or'),
                          'foo; bar; or baz')
         self.assertEqual(L, original)
-        self.failUnless(f(set(L)))
+        self.assertTrue(f(set(L)))
 
     def testCommaAndifyRaisesTypeError(self):
         L = [(2,)]
@@ -401,8 +401,8 @@ class StrTest(SupyTestCase):
     def testEllipsisify(self):
         f = utils.str.ellipsisify
         self.assertEqual(f('x'*30, 30), 'x'*30)
-        self.failUnless(len(f('x'*35, 30)) <= 30)
-        self.failUnless(f(' '.join(['xxxx']*10), 30)[:-3].endswith('xxxx'))
+        self.assertTrue(len(f('x'*35, 30)) <= 30)
+        self.assertTrue(f(' '.join(['xxxx']*10), 30)[:-3].endswith('xxxx'))
 
 
 class IterTest(SupyTestCase):
@@ -443,18 +443,18 @@ class IterTest(SupyTestCase):
 
     def testAny(self):
         any = utils.iter.any
-        self.failUnless(any(lambda i: i == 0, range(10)))
-        self.failIf(any(None, range(1)))
-        self.failUnless(any(None, range(2)))
-        self.failIf(any(None, []))
+        self.assertTrue(any(lambda i: i == 0, range(10)))
+        self.assertFalse(any(None, range(1)))
+        self.assertTrue(any(None, range(2)))
+        self.assertFalse(any(None, []))
 
     def testAll(self):
         all = utils.iter.all
-        self.failIf(all(lambda i: i == 0, range(10)))
-        self.failIf(all(lambda i: i % 2, range(2)))
-        self.failIf(all(lambda i: i % 2 == 0, [1, 3, 5]))
-        self.failUnless(all(lambda i: i % 2 == 0, [2, 4, 6]))
-        self.failUnless(all(None, ()))
+        self.assertFalse(all(lambda i: i == 0, range(10)))
+        self.assertFalse(all(lambda i: i % 2, range(2)))
+        self.assertFalse(all(lambda i: i % 2 == 0, [1, 3, 5]))
+        self.assertTrue(all(lambda i: i % 2 == 0, [2, 4, 6]))
+        self.assertTrue(all(None, ()))
 
     def testPartition(self):
         partition = utils.iter.partition
@@ -513,9 +513,9 @@ class FileTest(SupyTestCase):
 
     def testMktemp(self):
         # This is mostly to test that it actually halts.
-        self.failUnless(utils.file.mktemp())
-        self.failUnless(utils.file.mktemp())
-        self.failUnless(utils.file.mktemp())
+        self.assertTrue(utils.file.mktemp())
+        self.assertTrue(utils.file.mktemp())
+        self.assertTrue(utils.file.mktemp())
 
     def testSanitizeName(self):
         self.assertEqual(utils.file.sanitizeName('#foo'), '#foo')
@@ -525,22 +525,22 @@ class FileTest(SupyTestCase):
 class NetTest(SupyTestCase):
     def testEmailRe(self):
         emailRe = utils.net.emailRe
-        self.failUnless(emailRe.match('jemfinch@supybot.com'))
+        self.assertTrue(emailRe.match('jemfinch@supybot.com'))
 
     def testIsIP(self):
         isIP = utils.net.isIP
-        self.failIf(isIP('a.b.c'))
-        self.failIf(isIP('256.0.0.0'))
-        self.failIf(isIP('127.0.0.1 127.0.0.1'))
-        self.failUnless(isIP('0.0.0.0'))
-        self.failUnless(isIP('100.100.100.100'))
-        self.failUnless(isIP('255.255.255.255'))
+        self.assertFalse(isIP('a.b.c'))
+        self.assertFalse(isIP('256.0.0.0'))
+        self.assertFalse(isIP('127.0.0.1 127.0.0.1'))
+        self.assertTrue(isIP('0.0.0.0'))
+        self.assertTrue(isIP('100.100.100.100'))
+        self.assertTrue(isIP('255.255.255.255'))
 
     def testIsIPV6(self):
         f = utils.net.isIPV6
-        self.failIf(f('2001:: 2001::'))
-        self.failUnless(f('2001::'))
-        self.failUnless(f('2001:888:0:1::666'))
+        self.assertFalse(f('2001:: 2001::'))
+        self.assertTrue(f('2001::'))
+        self.assertTrue(f('2001:888:0:1::666'))
 
 class WebTest(SupyTestCase):
     def testGetDomain(self):
@@ -550,7 +550,7 @@ class WebTest(SupyTestCase):
     if network:
         def testGetUrlWithSize(self):
             url = 'http://slashdot.org/'
-            self.failUnless(len(utils.web.getUrl(url, 1024)) == 1024)
+            self.assertTrue(len(utils.web.getUrl(url, 1024)) == 1024)
 
 class FormatTestCase(SupyTestCase):
     def testNormal(self):
@@ -594,9 +594,9 @@ class RingBufferTestCase(SupyTestCase):
 
     def testNonzero(self):
         b = RingBuffer(3)
-        self.failIf(b)
+        self.assertFalse(b)
         b.append(1)
-        self.failUnless(b)
+        self.assertTrue(b)
 
     def testAppend(self):
         b = RingBuffer(3)
@@ -616,10 +616,10 @@ class RingBufferTestCase(SupyTestCase):
 
     def testContains(self):
         b = RingBuffer(3, range(3))
-        self.failUnless(0 in b)
-        self.failUnless(1 in b)
-        self.failUnless(2 in b)
-        self.failIf(3 in b)
+        self.assertTrue(0 in b)
+        self.assertTrue(1 in b)
+        self.assertTrue(2 in b)
+        self.assertFalse(3 in b)
 
     def testGetitem(self):
         L = range(10)
@@ -674,11 +674,11 @@ class RingBufferTestCase(SupyTestCase):
         b = RingBuffer(len(L), [0]*len(L))
         self.assertRaises(ValueError, b.__setitem__, slice(0, 10), [])
         b[2:4] = L[2:4]
-        self.assertEquals(b[2:4], L[2:4])
+        self.assertEqual(b[2:4], L[2:4])
         for _ in range(len(b)):
             b.append(0)
         b[2:4] = L[2:4]
-        self.assertEquals(b[2:4], L[2:4])
+        self.assertEqual(b[2:4], L[2:4])
 
     def testExtend(self):
         b = RingBuffer(3, range(3))
@@ -708,18 +708,18 @@ class RingBufferTestCase(SupyTestCase):
 
     def testEq(self):
         b = RingBuffer(3, range(3))
-        self.failIf(b == list(range(3)))
+        self.assertFalse(b == list(range(3)))
         b1 = RingBuffer(3)
-        self.failIf(b == b1)
+        self.assertFalse(b == b1)
         b1.append(0)
-        self.failIf(b == b1)
+        self.assertFalse(b == b1)
         b1.append(1)
-        self.failIf(b == b1)
+        self.assertFalse(b == b1)
         b1.append(2)
-        self.failUnless(b == b1)
+        self.assertTrue(b == b1)
         b = RingBuffer(100, range(10))
         b1 = RingBuffer(10, range(10))
-        self.failIf(b == b1)
+        self.assertFalse(b == b1)
 
     def testIter(self):
         b = RingBuffer(3, range(3))
@@ -771,11 +771,11 @@ class QueueTest(SupyTestCase):
 
     def testNonzero(self):
         q = queue()
-        self.failIf(q, 'queue not zero after initialization')
+        self.assertFalse(q, 'queue not zero after initialization')
         q.enqueue(1)
-        self.failUnless(q, 'queue zero after adding element')
+        self.assertTrue(q, 'queue zero after adding element')
         q.dequeue()
-        self.failIf(q, 'queue not zero after dequeue of only element')
+        self.assertFalse(q, 'queue not zero after dequeue of only element')
 
     def testLen(self):
         q = queue()
@@ -796,24 +796,24 @@ class QueueTest(SupyTestCase):
     def testEq(self):
         q1 = queue()
         q2 = queue()
-        self.failUnless(q1 == q1, 'queue not equal to itself')
-        self.failUnless(q2 == q2, 'queue not equal to itself')
-        self.failUnless(q1 == q2, 'initialized queues not equal')
+        self.assertTrue(q1 == q1, 'queue not equal to itself')
+        self.assertTrue(q2 == q2, 'queue not equal to itself')
+        self.assertTrue(q1 == q2, 'initialized queues not equal')
         q1.enqueue(1)
-        self.failUnless(q1 == q1, 'queue not equal to itself')
-        self.failUnless(q2 == q2, 'queue not equal to itself')
+        self.assertTrue(q1 == q1, 'queue not equal to itself')
+        self.assertTrue(q2 == q2, 'queue not equal to itself')
         q2.enqueue(1)
-        self.failUnless(q1 == q1, 'queue not equal to itself')
-        self.failUnless(q2 == q2, 'queue not equal to itself')
-        self.failUnless(q1 == q2, 'queues not equal after identical enqueue')
+        self.assertTrue(q1 == q1, 'queue not equal to itself')
+        self.assertTrue(q2 == q2, 'queue not equal to itself')
+        self.assertTrue(q1 == q2, 'queues not equal after identical enqueue')
         q1.dequeue()
-        self.failUnless(q1 == q1, 'queue not equal to itself')
-        self.failUnless(q2 == q2, 'queue not equal to itself')
-        self.failIf(q1 == q2, 'queues equal after one dequeue')
+        self.assertTrue(q1 == q1, 'queue not equal to itself')
+        self.assertTrue(q2 == q2, 'queue not equal to itself')
+        self.assertFalse(q1 == q2, 'queues equal after one dequeue')
         q2.dequeue()
-        self.failUnless(q1 == q2, 'queues not equal after both are dequeued')
-        self.failUnless(q1 == q1, 'queue not equal to itself')
-        self.failUnless(q2 == q2, 'queue not equal to itself')
+        self.assertTrue(q1 == q2, 'queues not equal after both are dequeued')
+        self.assertTrue(q1 == q1, 'queue not equal to itself')
+        self.assertTrue(q2 == q2, 'queue not equal to itself')
 
     def testInit(self):
         self.assertEqual(len(queue()), 0, 'queue len not 0 after init')
@@ -873,17 +873,17 @@ class QueueTest(SupyTestCase):
 
     def testContains(self):
         q = queue()
-        self.failIf(1 in q, 'empty queue cannot have elements')
+        self.assertFalse(1 in q, 'empty queue cannot have elements')
         q.enqueue(1)
-        self.failUnless(1 in q, 'recent enqueued element not in q')
+        self.assertTrue(1 in q, 'recent enqueued element not in q')
         q.enqueue(2)
-        self.failUnless(1 in q, 'original enqueued element not in q')
-        self.failUnless(2 in q, 'second enqueued element not in q')
+        self.assertTrue(1 in q, 'original enqueued element not in q')
+        self.assertTrue(2 in q, 'second enqueued element not in q')
         q.dequeue()
-        self.failIf(1 in q, 'dequeued element in q')
-        self.failUnless(2 in q, 'not dequeued element not in q')
+        self.assertFalse(1 in q, 'dequeued element in q')
+        self.assertTrue(2 in q, 'not dequeued element not in q')
         q.dequeue()
-        self.failIf(2 in q, 'dequeued element in q')
+        self.assertFalse(2 in q, 'dequeued element in q')
 
     def testIter(self):
         q1 = queue((1, 2, 3))
@@ -936,11 +936,11 @@ class SmallQueueTest(SupyTestCase):
 
     def testNonzero(self):
         q = queue()
-        self.failIf(q, 'queue not zero after initialization')
+        self.assertFalse(q, 'queue not zero after initialization')
         q.enqueue(1)
-        self.failUnless(q, 'queue zero after adding element')
+        self.assertTrue(q, 'queue zero after adding element')
         q.dequeue()
-        self.failIf(q, 'queue not zero after dequeue of only element')
+        self.assertFalse(q, 'queue not zero after dequeue of only element')
 
     def testLen(self):
         q = queue()
@@ -961,24 +961,24 @@ class SmallQueueTest(SupyTestCase):
     def testEq(self):
         q1 = queue()
         q2 = queue()
-        self.failUnless(q1 == q1, 'queue not equal to itself')
-        self.failUnless(q2 == q2, 'queue not equal to itself')
-        self.failUnless(q1 == q2, 'initialized queues not equal')
+        self.assertTrue(q1 == q1, 'queue not equal to itself')
+        self.assertTrue(q2 == q2, 'queue not equal to itself')
+        self.assertTrue(q1 == q2, 'initialized queues not equal')
         q1.enqueue(1)
-        self.failUnless(q1 == q1, 'queue not equal to itself')
-        self.failUnless(q2 == q2, 'queue not equal to itself')
+        self.assertTrue(q1 == q1, 'queue not equal to itself')
+        self.assertTrue(q2 == q2, 'queue not equal to itself')
         q2.enqueue(1)
-        self.failUnless(q1 == q1, 'queue not equal to itself')
-        self.failUnless(q2 == q2, 'queue not equal to itself')
-        self.failUnless(q1 == q2, 'queues not equal after identical enqueue')
+        self.assertTrue(q1 == q1, 'queue not equal to itself')
+        self.assertTrue(q2 == q2, 'queue not equal to itself')
+        self.assertTrue(q1 == q2, 'queues not equal after identical enqueue')
         q1.dequeue()
-        self.failUnless(q1 == q1, 'queue not equal to itself')
-        self.failUnless(q2 == q2, 'queue not equal to itself')
-        self.failIf(q1 == q2, 'queues equal after one dequeue')
+        self.assertTrue(q1 == q1, 'queue not equal to itself')
+        self.assertTrue(q2 == q2, 'queue not equal to itself')
+        self.assertFalse(q1 == q2, 'queues equal after one dequeue')
         q2.dequeue()
-        self.failUnless(q1 == q2, 'queues not equal after both are dequeued')
-        self.failUnless(q1 == q1, 'queue not equal to itself')
-        self.failUnless(q2 == q2, 'queue not equal to itself')
+        self.assertTrue(q1 == q2, 'queues not equal after both are dequeued')
+        self.assertTrue(q1 == q1, 'queue not equal to itself')
+        self.assertTrue(q2 == q2, 'queue not equal to itself')
 
     def testInit(self):
         self.assertEqual(len(queue()), 0, 'queue len not 0 after init')
@@ -1038,17 +1038,17 @@ class SmallQueueTest(SupyTestCase):
 
     def testContains(self):
         q = queue()
-        self.failIf(1 in q, 'empty queue cannot have elements')
+        self.assertFalse(1 in q, 'empty queue cannot have elements')
         q.enqueue(1)
-        self.failUnless(1 in q, 'recent enqueued element not in q')
+        self.assertTrue(1 in q, 'recent enqueued element not in q')
         q.enqueue(2)
-        self.failUnless(1 in q, 'original enqueued element not in q')
-        self.failUnless(2 in q, 'second enqueued element not in q')
+        self.assertTrue(1 in q, 'original enqueued element not in q')
+        self.assertTrue(2 in q, 'second enqueued element not in q')
         q.dequeue()
-        self.failIf(1 in q, 'dequeued element in q')
-        self.failUnless(2 in q, 'not dequeued element not in q')
+        self.assertFalse(1 in q, 'dequeued element in q')
+        self.assertTrue(2 in q, 'not dequeued element not in q')
         q.dequeue()
-        self.failIf(2 in q, 'dequeued element in q')
+        self.assertFalse(2 in q, 'dequeued element in q')
 
     def testIter(self):
         q1 = queue((1, 2, 3))
@@ -1089,28 +1089,28 @@ class MaxLengthQueueTestCase(SupyTestCase):
 class TwoWayDictionaryTestCase(SupyTestCase):
     def testInit(self):
         d = TwoWayDictionary(foo='bar')
-        self.failUnless('foo' in d)
-        self.failUnless('bar' in d)
+        self.assertTrue('foo' in d)
+        self.assertTrue('bar' in d)
 
         d = TwoWayDictionary({1: 2})
-        self.failUnless(1 in d)
-        self.failUnless(2 in d)
+        self.assertTrue(1 in d)
+        self.assertTrue(2 in d)
 
     def testSetitem(self):
         d = TwoWayDictionary()
         d['foo'] = 'bar'
-        self.failUnless('foo' in d)
-        self.failUnless('bar' in d)
+        self.assertTrue('foo' in d)
+        self.assertTrue('bar' in d)
 
     def testDelitem(self):
         d = TwoWayDictionary(foo='bar')
         del d['foo']
-        self.failIf('foo' in d)
-        self.failIf('bar' in d)
+        self.assertFalse('foo' in d)
+        self.assertFalse('bar' in d)
         d = TwoWayDictionary(foo='bar')
         del d['bar']
-        self.failIf('bar' in d)
-        self.failIf('foo' in d)
+        self.assertFalse('bar' in d)
+        self.assertFalse('foo' in d)
 
 
 class TestTimeoutQueue(SupyTestCase):
@@ -1143,18 +1143,18 @@ class TestTimeoutQueue(SupyTestCase):
     def testContains(self):
         q = TimeoutQueue(1)
         q.enqueue(1)
-        self.failUnless(1 in q)
-        self.failUnless(1 in q) # For some reason, the second one might fail.
-        self.failIf(2 in q)
+        self.assertTrue(1 in q)
+        self.assertTrue(1 in q) # For some reason, the second one might fail.
+        self.assertFalse(2 in q)
         timeFastForward(1.1)
-        self.failIf(1 in q)
+        self.assertFalse(1 in q)
 
     def testReset(self):
         q = TimeoutQueue(10)
         q.enqueue(1)
-        self.failUnless(1 in q)
+        self.assertTrue(1 in q)
         q.reset()
-        self.failIf(1 in q)
+        self.assertFalse(1 in q)
 
 class TestCacheDict(SupyTestCase):
     def testMaxNeverExceeded(self):
@@ -1162,22 +1162,22 @@ class TestCacheDict(SupyTestCase):
         d = CacheDict(10)
         for i in xrange(max**2):
             d[i] = i
-            self.failUnless(len(d) <= max)
-            self.failUnless(i in d)
-            self.failUnless(d[i] == i)
+            self.assertTrue(len(d) <= max)
+            self.assertTrue(i in d)
+            self.assertTrue(d[i] == i)
 
 class TestTruncatableSet(SupyTestCase):
     def testBasics(self):
         s = TruncatableSet(['foo', 'bar', 'baz', 'qux'])
         self.assertEqual(s, set(['foo', 'bar', 'baz', 'qux']))
-        self.failUnless('foo' in s)
-        self.failUnless('bar' in s)
-        self.failIf('quux' in s)
+        self.assertTrue('foo' in s)
+        self.assertTrue('bar' in s)
+        self.assertFalse('quux' in s)
         s.discard('baz')
-        self.failUnless('foo' in s)
-        self.failIf('baz' in s)
+        self.assertTrue('foo' in s)
+        self.assertFalse('baz' in s)
         s.add('quux')
-        self.failUnless('quux' in s)
+        self.assertTrue('quux' in s)
 
     def testTruncate(self):
         s = TruncatableSet(['foo', 'bar'])
